<?php
namespace Zeedhi\ReportWebService\Services;

use Zeedhi\Report\LogoConfig;
use Zeedhi\Report\ReportBuilder;

/**
*   Make everything that is necessary to generate and read the report.
*/
class Report {

    /** @var $reportPath The path to the report. */
    protected $reportPath;
    /** @var $templatePath The path to the template. */
    protected $templatePath;
    /** @var $assetsPath The path to the assets. */
    protected $assetsPath;
    /**
     * Constructor.
     *
     * @param $reportPath The path to the report
     * @param $templatePath The path to the template.
     * @param $assetsPath The path to the assets.
     *
     */
    public function __construct($reportPath) {
        $this->reportPath = $reportPath;

    }

    /**
     * Validates the metaData.
     *
     * @param $reportMetaData The meta data to build the report.
     */
    protected function validateMetaData($reportMetaData) {
        static $propertiesToValidate = array(
            "title", "reportName"
        );
        foreach($propertiesToValidate as $propertyName) {
            if (!isset($reportMetaData[$propertyName])) {
                throw Exception::missingProperty($propertyName);
            }
        }
    }

    /**
     * Generates the report.
     *
     * @param $reportMetaData The meta data to build the report.
     * @param $reportDataSet The meta data to the report.
     * @param $reportFilter The meta filter to build the report.
     */
    public function generateReport($reportMetaData, $reportDataSet, $reportFilter, $isWebService = true) {
        $this->validateMetaData($reportMetaData);

        $reportOrderBy = [];
        foreach ($reportFilter as $condition) {
            if(is_array($condition["name"])){
                $reportOrderBy = array_merge($reportOrderBy, $condition["name"]);
            }
        }

        $reportName = uniqid().".pdf";

        $reportName = str_replace(' ', '', $reportName);

        $targetFile = $this->reportPath.$reportName;

        $logoConfig = new LogoConfig();
        if (isset($reportMetaData['clientLogo'])) {
            $logoConfig->setClientLogo($reportMetaData['clientLogo']);
        }

        if (isset($reportMetaData['enterpriseLogo'])) {
            $logoConfig->setEnterpriseLogo($reportMetaData['enterpriseLogo']);
        }

        if (isset($reportMetaData['productLogo'])) {
            $logoConfig->setProductLogo($reportMetaData['productLogo']);
        }

        $builder = new ReportBuilder(
            $reportMetaData,
            $reportDataSet,
            $logoConfig,
            $this->templatePath,
            "seems unused", //@todo remove this param.
            $targetFile,
            $this->assetsPath,
            $isWebService
        );

        $builder->buildReport("pdf");

        return $reportName;
    }
}