<?php
namespace Zeedhi\ReportWebService\SpreadSheet;

use Zeedhi\ReportWebService\SpreadSheet\SpreadsheetWriter;

/**
 * The implementation of the main controller on the webservice.
 */
class EscapeFunction implements SpreadsheetWriter {

    /** @var SpreadsheetWriter $spreadsheetWriter The main controller on the webservice. */
    protected $spreadsheetWriter;

    /**
     * Constructor.
     *
     * @param $spreadsheetWriter SpreadsheetWriter The main controller on the webservice.
     */
    function __construct(SpreadsheetWriter $spreadsheetWriter){
        $this->spreadsheetWriter = $spreadsheetWriter;
    }

    /**
     * Creates the XLS file.
     *
     * @param $gridData The grid data.
     * @param $metaData The meta data to build the report.
     *
     * @return The generated file's name.
     */
    public function generateXLS($gridData, $metaData){
        $gridData = $this->getEscapedGridData($gridData);
        $fileName = $this->spreadsheetWriter->generateXLS($gridData, $metaData);
        return $fileName;
    }

    /**
     * Formats the grid data to build the XLS file.
     *
     * @param $gridData The grid data.
     *
     * @return The formarted grid data.
     */
    private function getEscapedGridData($gridData){
        for($i=0; $i < count($gridData); $i++){
            for($j=0; $j < count($gridData[$i]); $j++){
                if(isset($gridData[$i][$j]{0}) && $gridData[$i][$j]{0} == '='){
                    $gridData[$i][$j] = "'".$gridData[$i][$j];
                }
            }
        }
        return $gridData;
    }
}