<?php
namespace tests\Zeedhi\ReportWebService\Controllers;

use Zeedhi\ReportWebService\Controllers\XLSCreator;
use Zeedhi\ReportWebService\SpreadSheet\XLSXWriter;
use Zeedhi\ReportWebService\Services\ReportInfoManager;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\ReportWebService\Controllers\ReportGenerator;

class XLSCreatorTest extends \PHPUnit\Framework\TestCase {

    /** @var XLSCreator */
    /** @var XLSXWriter */
    protected $xlsCreator;
    protected $xlsxWriter;
    private $reportInfoManager;
    protected $row = array(
        "dataSet" => [
            ["CODE","EMPLOYEE_NAME","SALARY"],
            ["1","Alexander",7000,],
            ["1.1","Alberto",12000,],
            ["1.1.1","Allan",9000,],
            ["2","Alyssa",8800,],
            ["2.1","Alana",3100,]
        ],
        "metaData" => ["reportName" => "xlsCreator", "columns" => [
            "CODE" => ['description' => 'Code',
                       'format' => ['type' => 'number',
                                    'params' => ['precision' => 2] ] ],
            "EMPLOYEE_NAME" => ['description' => 'Employee_name',
                                'format' => ['type' => 'float'] ],
            "SALARY"        => ['description' => 'Salary']
            ], "xlsDefaultType" => 'default'
        ],
        "filter" => []
    );

    public function setUp(){
        $this->reportInfoManager = $this->getMockBuilder(ReportInfoManager::class)
            ->disableOriginalConstructor()
            ->getMock();
        $this->xlsxWriter = new XLSXWriter(__DIR__."/../../../../reports/");
        $this->xlsCreator = new ReportGenerator($this->xlsxWriter, $this->reportInfoManager);
    }

    public function testGenerateXLS() {
        $this->row = array(
            'dataSet' => json_encode($this->row['dataSet']),
            'metaData' => json_encode($this->row['metaData']),
            'filter' => json_encode($this->row['filter'])
        );
        $this->request = $this->getMockBuilder(SomeClass::class)
                              ->setMethods(array("getRow"))
                              ->getMock();
        $row = new Row($this->row, $this->request, "", 1);
        $response = new Response();
        $this->xlsCreator->generateXLS($row, $response);
    }

    public function testGenerateXLSWithException() {
        $this->row['metaData'] = array();
        $this->row = array(
            'dataSet' => json_encode($this->row['dataSet']),
            'metaData' => json_encode($this->row['metaData']),
            'filter' => json_encode($this->row['filter'])
        );
        $this->request = $this->getMockBuilder(SomeClass::class)
                              ->setMethods(array("getRow"))
                              ->getMock();
        $row = new Row($this->row, $this->request, "", 1);
        $response = new Response();
        $this->xlsCreator->generateXLS($row, $response);
        $this->assertNotEmpty($response->getError());
    }
}