<?php
namespace tests\Zeedhi\ReportWebService\Services;

use Zeedhi\ReportWebService\Services\Report;

class ReportTest extends \PHPUnit\Framework\TestCase {

    /** @var Report */
    protected $reportService;
    protected $dataSet = array(
        array("COUNTRY_ID" => "FR", "COUNTRY_NAME" => "France", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "UK", "COUNTRY_NAME" => "United Kingdom", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "NL", "COUNTRY_NAME" => "Netherlands", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "IT", "COUNTRY_NAME" => "Italy", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "DK", "COUNTRY_NAME" => "Denmark", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "DE", "COUNTRY_NAME" => "Germany", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "CH", "COUNTRY_NAME" => "Switzerland", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "BE", "COUNTRY_NAME" => "Belgium", "REGION_NAME" => "Europa"),
        array("COUNTRY_ID" => "AR", "COUNTRY_NAME" => "Argentina", "REGION_NAME" => "America"),
        array("COUNTRY_ID" => "MX", "COUNTRY_NAME" => "Mexico", "REGION_NAME" => "America"),
        array("COUNTRY_ID" => "CA", "COUNTRY_NAME" => "Canada", "REGION_NAME" => "America"),
        array("COUNTRY_ID" => "US", "COUNTRY_NAME" => "United States of America", "REGION_NAME" => "America"),
        array("COUNTRY_ID" => "BR", "COUNTRY_NAME" => "Brasil", "REGION_NAME" => "America"),
        array("COUNTRY_ID" => "CN", "COUNTRY_NAME" => "China", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "HK", "COUNTRY_NAME" => "HongKong", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "SG", "COUNTRY_NAME" => "Singapore", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "IN", "COUNTRY_NAME" => "India", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "JP", "COUNTRY_NAME" => "Japan", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "AU", "COUNTRY_NAME" => "Australia", "REGION_NAME" => "Asia"),
        array("COUNTRY_ID" => "KW", "COUNTRY_NAME" => "Kuwait", "REGION_NAME" => "Middle East and Africa"),
        array("COUNTRY_ID" => "IL", "COUNTRY_NAME" => "Israel", "REGION_NAME" => "Middle East and Africa"),
        array("COUNTRY_ID" => "EG", "COUNTRY_NAME" => "Egypt", "REGION_NAME" => "Middle East and Africa"),
        array("COUNTRY_ID" => "NG", "COUNTRY_NAME" => "Nigeria", "REGION_NAME" => "Middle East and Africa"),
        array("COUNTRY_ID" => "AT", "COUNTRY_NAME" => "Austrália", "REGION_NAME" => "Oceania")
    );

    protected $reportMetaData = array(
        "name"  => "countries_by_regions",
        "title" => "Contries by Regions",
        "reportName" => "report",
        "version" => "1.0a",
        "orientation" => "PORTRAIT",
        "lang"=>"pt_br",
        "columns" => array(
            "COUNTRY_ID" => array(
                "descricao" => "Id",
                "size" => "20%",
                "align" => "left",
                "format" => null,
                "sequence" => 1,
                "description" => "a"
            ),
            "COUNTRY_NAME" => array(
                "descricao" => "Country Name",
                "size" => "50%",
                "align" => "left",
                "format" => null,
                "sequence" => 2,
                "description" => "a"
            ),
            "REGION_NAME" => array(
                "descricao" => "Region Name",
                "size" => "30%",
                "align" => "left",
                "format" => null,
                "sequence" => 3,
                "description" => "a"
            ),
        ),
        "groups" => array(),
        "reportSummary" => array(
            "label"      => "Total of countries",
            "expression" => "COUNT(*)"
        ),
        'clientLogo' => 'http://localhost/static/images/logo/logo-cliente.gif',
        'enterpriseLogo' => 'http://localhost/static/images/zeedhi-logo-min.png',
        'productLogo' => 'http://localhost/static/images/zeedhi-logo.png',
        'words'=> array(
            "Página"=> "Página",
            "Relatório"=> "Relatório",
            "Versão"=> "Versão"
        )
    );

    protected $filter = [];

    public function setUp() {
        $this->reportService = new Report(realpath(__DIR__."/reports/"));
    }

    public function testPrintReport(){
        $this->reportStub = $this->getMockBuilder(Report::class, ['readFile'])
            ->disableOriginalConstructor()
            ->getMock();
        $reportName = $this->reportStub->generateReport($this->reportMetaData, $this->dataSet, $this->filter);
    }

    /**
     * @expectedException        Exception
     */
    public function testValidateMetaDataError(){
        $reportMetaData = array("name" => "errorTest");
        $this->reportService->generateReport($reportMetaData, $this->dataSet, $this->filter);
    }

    /**
     * @expectedException        Exception
     */
    public function testPrintReportError(){
        $this->reportService->generateReport("", array(), array());
    }
}
