<?php
namespace tests\Zeedhi\ReportWebService\SpreadSheet;

use tests\Zeedhi\ReportWebService\CreatorMocks\XLSXWriter;
use Zeedhi\ReportWebService\SpreadSheet\EscapeFunction;

class EscapeFunctionTest extends \PHPUnit\Framework\TestCase {

    /** @var XLSXWriter */
    protected $xlsCreator;

    /** @var EscapeFunction */
    protected $escapeFunction;

    protected function setUp() {
        $this->xlsCreator = new XLSXWriter();
        $this->escapeFunction = new EscapeFunction($this->xlsCreator);
    }

    public function testGenerateXLS() {
        $fileName = $this->escapeFunction->generateXLS([
            ["=Employee ID","First Name","Last Name","Job ID","Salary","Manager ID","Department ID"],
            ["103","=Alexander","Hunold","IT_PROG",7000,"102","60"]
        ], ["columns" => []]);
        $escapedGrid = $this->xlsCreator->getXLSGridData();
        $this->assertEquals("PLACEHOLDER", $fileName);
        $this->assertCount(2, $escapedGrid, "Number of rows must be the same.");
        $this->assertEquals("'=Employee ID", $escapedGrid[0][0]);
        $this->assertEquals("103", $escapedGrid[1][0]);
        $this->assertEquals("'=Alexander", $escapedGrid[1][1]);
    }

    public function testGenerateXLSWithXLSType() {
        $fileName = $this->escapeFunction->generateXLS([
            ["=Employee ID","First Name","Last Name","Job ID","Salary","Manager ID","Department ID"],
            ["103","=Alexander","Hunold","IT_PROG",7000,"102","60"]
        ], ["columns" => [
            ["xlsType"=> "integer", "name"=> "Salary"]
        ]]);
        $escapedGrid = $this->xlsCreator->getXLSGridData();
        $this->assertEquals("PLACEHOLDER", $fileName);
        $this->assertCount(2, $escapedGrid, "Number of rows must be the same.");
        $this->assertEquals("'=Employee ID", $escapedGrid[0][0]);
        $this->assertEquals("103", $escapedGrid[1][0]);
        $this->assertEquals("'=Alexander", $escapedGrid[1][1]);
    }

    public function testGenerateXLSWithEmptyString() {
        $fileName = $this->escapeFunction->generateXLS([
            ["=Employee ID","First Name","Last Name","Job ID","Salary","Manager ID","Department ID"],
            ["103","=Alexander","Hunold","IT_PROG",7000,"102",""]
        ], ["columns" => []]);
        $escapedGrid = $this->xlsCreator->getXLSGridData();
        $this->assertEquals("PLACEHOLDER", $fileName);
        $this->assertCount(2, $escapedGrid, "Number of rows must be the same.");
        $this->assertEquals("'=Employee ID", $escapedGrid[0][0]);
        $this->assertEquals("103", $escapedGrid[1][0]);
        $this->assertEquals("'=Alexander", $escapedGrid[1][1]);
        $this->assertEquals("", $escapedGrid[1][6]);
    }
}
